@@ -12,9 +12,16 @@ class Enums:
     CREATE = 'Crear'
     UPDATE = 'Actualizar'
     DELETE = 'Eliminar'
+    SENT = 'Enviada'
+    RECEIVED = 'Recibidas'
+    PENDING = 'Pendientes'
+    AUTHORIZED = 'Autorizada'
+    LIST_AUTHORIZE_ROLE = [SENT, RECEIVED, PENDING, AUTHORIZED]
+
 
 class Constants:
     FORMAT_DATE_TIME = '%d-%m-%Y %H:%M:%S'
+    FORMAT_DATE_TIME_12 = '%d-%m-%Y %I:%M %p'
     FORMAT_DATE = '%d-%m-%Y'
     FORMAT_DATE_OLD = '%Y-%m-%d'
     FORMAT_TIME = '%H:%M:%S'
